@@ -77,8 +77,8 @@ Revisions
 
 """
 try:
-    from gTixi import alib, waFile, waText
-    from gTixi.alib import alib
+    from . import alib, waFile, waText
+    from .alib import alib
 except:
     from alib import alib,waFile,waText
 aWaEnv={'sWal':'WalArtmin'}
@@ -680,8 +680,8 @@ aI2c='''[#comment|此体系中器件有统一i2c地址]
 [0x68|DS3231时钟模块（Pioneer600）]
 [0x76|BMP280温度压力传感（Pioneer600）]
 [0x77|BME280温湿度压力传感器]'''
-
-print(str(aWaEnv))
+strWaEnv = str(aWaEnv).replace("{","[").replace("}","]").replace(": ","|").replace("'","").replace(", ","][")
+print(strWaEnv)
 
 if __name__ == "__main__":
     pass
